package javax.management.loading;

import java.security.AccessController;
import java.security.PrivilegedAction;
import java.io.InputStream;
import java.io.FileOutputStream;
import java.nio.file.Files;
import java.nio.file.attribute.FileAttribute;
import java.io.ObjectInput;
import java.io.ObjectOutput;
import java.util.Iterator;
import java.io.IOException;
import javax.management.InstanceNotFoundException;
import javax.management.NotCompliantMBeanException;
import javax.management.MBeanException;
import javax.management.MBeanRegistrationException;
import javax.management.InstanceAlreadyExistsException;
import javax.management.ReflectionException;
import javax.management.ObjectInstance;
import java.util.StringTokenizer;
import java.util.HashSet;
import com.sun.jmx.remote.util.EnvHelp;
import java.io.File;
import java.util.Set;
import java.net.MalformedURLException;
import javax.management.ServiceNotFoundException;
import java.util.logging.Level;
import com.sun.jmx.defaults.JmxProperties;
import java.util.Arrays;
import java.util.HashMap;
import java.util.ArrayList;
import java.net.URLStreamHandlerFactory;
import java.util.Map;
import java.net.URL;
import javax.management.ObjectName;
import java.util.List;
import javax.management.MBeanServer;
import java.io.Externalizable;
import javax.management.MBeanRegistration;
import java.net.URLClassLoader;

public class MLet extends URLClassLoader implements MLetMBean, MBeanRegistration, Externalizable
{
    private static final long serialVersionUID = 3636148327800330130L;
    private MBeanServer server;
    private List<MLetContent> mletList;
    private String libraryDirectory;
    private ObjectName mletObjectName;
    private URL[] myUrls;
    private transient ClassLoaderRepository currentClr;
    private transient boolean delegateToCLR;
    private Map<String, Class<?>> primitiveClasses;
    
    public MLet() {
        this(new URL[0]);
    }
    
    public MLet(URL[] array) {
        this(array, true);
    }
    
    public MLet(URL[] array, ClassLoader classLoader) {
        this(array, classLoader, true);
    }
    
    public MLet(URL[] array, ClassLoader classLoader, URLStreamHandlerFactory urlStreamHandlerFactory) {
        this(array, classLoader, urlStreamHandlerFactory, true);
    }
    
    public MLet(URL[] urls, boolean b) {
        super(urls);
        this.server = null;
        this.mletList = new ArrayList();
        this.mletObjectName = null;
        this.myUrls = null;
        (this.primitiveClasses = new HashMap(8)).put(Boolean.TYPE.toString(), Boolean.class);
        this.primitiveClasses.put(Character.TYPE.toString(), Character.class);
        this.primitiveClasses.put(Byte.TYPE.toString(), Byte.class);
        this.primitiveClasses.put(Short.TYPE.toString(), Short.class);
        this.primitiveClasses.put(Integer.TYPE.toString(), Integer.class);
        this.primitiveClasses.put(Long.TYPE.toString(), Long.class);
        this.primitiveClasses.put(Float.TYPE.toString(), Float.class);
        this.primitiveClasses.put(Double.TYPE.toString(), Double.class);
        this.init(b);
    }
    
    public MLet(URL[] urls, ClassLoader parent, boolean b) {
        super(urls, parent);
        this.server = null;
        this.mletList = new ArrayList();
        this.mletObjectName = null;
        this.myUrls = null;
        (this.primitiveClasses = new HashMap(8)).put(Boolean.TYPE.toString(), Boolean.class);
        this.primitiveClasses.put(Character.TYPE.toString(), Character.class);
        this.primitiveClasses.put(Byte.TYPE.toString(), Byte.class);
        this.primitiveClasses.put(Short.TYPE.toString(), Short.class);
        this.primitiveClasses.put(Integer.TYPE.toString(), Integer.class);
        this.primitiveClasses.put(Long.TYPE.toString(), Long.class);
        this.primitiveClasses.put(Float.TYPE.toString(), Float.class);
        this.primitiveClasses.put(Double.TYPE.toString(), Double.class);
        this.init(b);
    }
    
    public MLet(URL[] urls, ClassLoader parent, URLStreamHandlerFactory factory, boolean b) {
        super(urls, parent, factory);
        this.server = null;
        this.mletList = new ArrayList();
        this.mletObjectName = null;
        this.myUrls = null;
        (this.primitiveClasses = new HashMap(8)).put(Boolean.TYPE.toString(), Boolean.class);
        this.primitiveClasses.put(Character.TYPE.toString(), Character.class);
        this.primitiveClasses.put(Byte.TYPE.toString(), Byte.class);
        this.primitiveClasses.put(Short.TYPE.toString(), Short.class);
        this.primitiveClasses.put(Integer.TYPE.toString(), Integer.class);
        this.primitiveClasses.put(Long.TYPE.toString(), Long.class);
        this.primitiveClasses.put(Float.TYPE.toString(), Float.class);
        this.primitiveClasses.put(Double.TYPE.toString(), Double.class);
        this.init(b);
    }
    
    private void init(boolean delegateToCLR) {
        this.delegateToCLR = delegateToCLR;
        try {
            this.libraryDirectory = System.getProperty("jmx.mlet.library.dir");
            if (this.libraryDirectory == null) {
                this.libraryDirectory = this.getTmpDir();
            }
        }
        catch (SecurityException ex) {}
    }
    
    @Override
    public void addURL(URL url) {
        if (!Arrays.asList(this.getURLs()).contains(url)) {
            super.addURL(url);
        }
    }
    
    @Override
    public void addURL(String s) throws ServiceNotFoundException {
        try {
            URL url = new URL(s);
            if (!Arrays.asList(this.getURLs()).contains(url)) {
                super.addURL(url);
            }
        }
        catch (MalformedURLException thrown) {
            if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "addUrl", "Malformed URL: " + s, thrown);
            }
            throw new ServiceNotFoundException("The specified URL is malformed");
        }
    }
    
    @Override
    public URL[] getURLs() {
        return super.getURLs();
    }
    
    @Override
    public Set<Object> getMBeansFromURL(URL url) throws ServiceNotFoundException {
        if (url == null) {
            throw new ServiceNotFoundException("The specified URL is null");
        }
        return this.getMBeansFromURL(url.toString());
    }
    
    @Override
    public Set<Object> getMBeansFromURL(String replace) throws ServiceNotFoundException {
        String s = "getMBeansFromURL";
        if (this.server == null) {
            throw new IllegalStateException("This MLet MBean is not registered with an MBeanServer.");
        }
        if (replace == null) {
            JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, "URL is null");
            throw new ServiceNotFoundException("The specified URL is null");
        }
        replace = replace.replace(File.separatorChar, '/');
        if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, "<URL = " + replace + ">");
        }
        try {
            this.mletList = new MLetParser().parseURL(replace);
        }
        catch (Exception cause) {
            String string = "Problems while parsing URL [" + replace + "], got exception [" + cause.toString() + "]";
            JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, string);
            throw (ServiceNotFoundException)EnvHelp.initCause(new ServiceNotFoundException(string), cause);
        }
        if (this.mletList.size() == 0) {
            String string2 = "File " + replace + " not found or MLET tag not defined in file";
            JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, string2);
            throw new ServiceNotFoundException(string2);
        }
        HashSet set = new HashSet();
        for (MLetContent mLetContent : this.mletList) {
            String str = mLetContent.getCode();
            if (str != null && str.endsWith(".class")) {
                str = str.substring(0, str.length() - 6);
            }
            String name = mLetContent.getName();
            URL obj = mLetContent.getCodeBase();
            String version = mLetContent.getVersion();
            String serializedObject = mLetContent.getSerializedObject();
            String jarFiles = mLetContent.getJarFiles();
            URL documentBase = mLetContent.getDocumentBase();
            if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINER)) {
                JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, "\n\tMLET TAG     = " + mLetContent.getAttributes() + "\n\tCODEBASE     = " + obj + "\n\tARCHIVE      = " + jarFiles + "\n\tCODE         = " + str + "\n\tOBJECT       = " + serializedObject + "\n\tNAME         = " + name + "\n\tVERSION      = " + version + "\n\tDOCUMENT URL = " + documentBase);
            }
            StringTokenizer o = new StringTokenizer(jarFiles, ",", false);
            while (o.hasMoreTokens()) {
                String trim = o.nextToken().trim();
                if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINER)) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, "Load archive for codebase <" + obj + ">, file <" + trim + ">");
                }
                try {
                    obj = this.check(version, obj, trim, mLetContent);
                }
                catch (Exception thrown) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), s, "Got unexpected exception", thrown);
                    set.add(thrown);
                    continue;
                }
                try {
                    if (!Arrays.asList(this.getURLs()).contains(new URL(obj.toString() + trim))) {
                        this.addURL(obj + trim);
                    }
                    else {
                        continue;
                    }
                }
                catch (MalformedURLException ex) {}
            }
            if (str != null && serializedObject != null) {
                JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, "CODE and OBJECT parameters cannot be specified at the same time in tag MLET");
                set.add(new Error("CODE and OBJECT parameters cannot be specified at the same time in tag MLET"));
            }
            else if (str == null && serializedObject == null) {
                JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, "Either CODE or OBJECT parameter must be specified in tag MLET");
                set.add(new Error("Either CODE or OBJECT parameter must be specified in tag MLET"));
            }
            else {
                ObjectInstance objectInstance;
                try {
                    if (str != null) {
                        List<String> parameterTypes = mLetContent.getParameterTypes();
                        List<String> parameterValues = mLetContent.getParameterValues();
                        ArrayList o2 = new ArrayList();
                        for (int i = 0; i < parameterTypes.size(); ++i) {
                            o2.add(this.constructParameter((String)parameterValues.get(i), (String)parameterTypes.get(i)));
                        }
                        if (parameterTypes.isEmpty()) {
                            if (name == null) {
                                objectInstance = this.server.createMBean(str, null, this.mletObjectName);
                            }
                            else {
                                objectInstance = this.server.createMBean(str, new ObjectName(name), this.mletObjectName);
                            }
                        }
                        else {
                            Object[] array = o2.toArray();
                            String[] array2 = new String[parameterTypes.size()];
                            parameterTypes.toArray(array2);
                            if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINEST)) {
                                StringBuilder o3 = new StringBuilder();
                                for (int j = 0; j < array2.length; ++j) {
                                    o3.append("\n\tSignature     = ").append(array2[j]).append("\t\nParams        = ").append(array[j]);
                                }
                                JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), s, o3.toString());
                            }
                            if (name == null) {
                                objectInstance = this.server.createMBean(str, null, this.mletObjectName, array, array2);
                            }
                            else {
                                objectInstance = this.server.createMBean(str, new ObjectName(name), this.mletObjectName, array, array2);
                            }
                        }
                    }
                    else {
                        Object loadSerializedObject = this.loadSerializedObject(obj, serializedObject);
                        if (name == null) {
                            this.server.registerMBean(loadSerializedObject, null);
                        }
                        else {
                            this.server.registerMBean(loadSerializedObject, new ObjectName(name));
                        }
                        objectInstance = new ObjectInstance(name, loadSerializedObject.getClass().getName());
                    }
                }
                catch (ReflectionException thrown2) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, "ReflectionException", thrown2);
                    set.add(thrown2);
                    continue;
                }
                catch (InstanceAlreadyExistsException thrown3) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, "InstanceAlreadyExistsException", thrown3);
                    set.add(thrown3);
                    continue;
                }
                catch (MBeanRegistrationException thrown4) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, "MBeanRegistrationException", thrown4);
                    set.add(thrown4);
                    continue;
                }
                catch (MBeanException thrown5) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, "MBeanException", thrown5);
                    set.add(thrown5);
                    continue;
                }
                catch (NotCompliantMBeanException thrown6) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, "NotCompliantMBeanException", thrown6);
                    set.add(thrown6);
                    continue;
                }
                catch (InstanceNotFoundException thrown7) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, "InstanceNotFoundException", thrown7);
                    set.add(thrown7);
                    continue;
                }
                catch (IOException thrown8) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, "IOException", thrown8);
                    set.add(thrown8);
                    continue;
                }
                catch (SecurityException thrown9) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, "SecurityException", thrown9);
                    set.add(thrown9);
                    continue;
                }
                catch (Exception thrown10) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, "Exception", thrown10);
                    set.add(thrown10);
                    continue;
                }
                catch (Error thrown11) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), s, "Error", thrown11);
                    set.add(thrown11);
                    continue;
                }
                set.add(objectInstance);
            }
        }
        return set;
    }
    
    @Override
    public synchronized String getLibraryDirectory() {
        return this.libraryDirectory;
    }
    
    @Override
    public synchronized void setLibraryDirectory(String libraryDirectory) {
        this.libraryDirectory = libraryDirectory;
    }
    
    @Override
    public ObjectName preRegister(MBeanServer mBeanServer, ObjectName mletObjectName) throws Exception {
        this.setMBeanServer(mBeanServer);
        if (mletObjectName == null) {
            mletObjectName = new ObjectName(mBeanServer.getDefaultDomain() + ":" + "type=MLet");
        }
        return this.mletObjectName = mletObjectName;
    }
    
    @Override
    public void postRegister(Boolean b) {
    }
    
    @Override
    public void preDeregister() throws Exception {
    }
    
    @Override
    public void postDeregister() {
    }
    
    @Override
    public void writeExternal(ObjectOutput objectOutput) throws IOException, UnsupportedOperationException {
        throw new UnsupportedOperationException("MLet.writeExternal");
    }
    
    @Override
    public void readExternal(ObjectInput objectInput) throws IOException, ClassNotFoundException, UnsupportedOperationException {
        throw new UnsupportedOperationException("MLet.readExternal");
    }
    
    public synchronized Class<?> loadClass(String name, ClassLoaderRepository currentClr) throws ClassNotFoundException {
        ClassLoaderRepository currentClr2 = this.currentClr;
        try {
            this.currentClr = currentClr;
            return this.loadClass(name);
        }
        finally {
            this.currentClr = currentClr2;
        }
    }
    
    @Override
    protected Class<?> findClass(String s) throws ClassNotFoundException {
        return this.findClass(s, this.currentClr);
    }
    
    Class<?> findClass(String s, ClassLoaderRepository classLoaderRepository) throws ClassNotFoundException {
        Class<Object> clazz = null;
        JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), "findClass", s);
        try {
            clazz = super.findClass(s);
            if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINER)) {
                JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), "findClass", "Class " + s + " loaded through MLet classloader");
            }
        }
        catch (ClassNotFoundException ex) {
            if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "findClass", "Class " + s + " not found locally");
            }
        }
        if (clazz == null && this.delegateToCLR && classLoaderRepository != null) {
            try {
                if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINEST)) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "findClass", "Class " + s + " : looking in CLR");
                }
                clazz = classLoaderRepository.loadClassBefore(this, s);
                if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINER)) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), "findClass", "Class " + s + " loaded through the default classloader repository");
                }
            }
            catch (ClassNotFoundException ex2) {
                if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINEST)) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "findClass", "Class " + s + " not found in CLR");
                }
            }
        }
        if (clazz == null) {
            JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "findClass", "Failed to load class " + s);
            throw new ClassNotFoundException(s);
        }
        return clazz;
    }
    
    @Override
    protected String findLibrary(String str) {
        String sourceMethod = "findLibrary";
        String mapLibraryName = System.mapLibraryName(str);
        if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), sourceMethod, "Search " + str + " in all JAR files");
        }
        if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), sourceMethod, "loadLibraryAsResource(" + mapLibraryName + ")");
        }
        String loadLibraryAsResource = this.loadLibraryAsResource(mapLibraryName);
        if (loadLibraryAsResource != null) {
            if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINER)) {
                JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), sourceMethod, mapLibraryName + " loaded, absolute path = " + loadLibraryAsResource);
                return loadLibraryAsResource;
            }
            return loadLibraryAsResource;
        }
        else {
            String string = removeSpace(System.getProperty("os.name")) + File.separator + removeSpace(System.getProperty("os.arch")) + File.separator + removeSpace(System.getProperty("os.version")) + File.separator + "lib" + File.separator + mapLibraryName;
            if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINER)) {
                JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), sourceMethod, "loadLibraryAsResource(" + string + ")");
            }
            String loadLibraryAsResource2 = this.loadLibraryAsResource(string);
            if (loadLibraryAsResource2 != null) {
                if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINER)) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), sourceMethod, string + " loaded, absolute path = " + loadLibraryAsResource2);
                    return loadLibraryAsResource2;
                }
                return loadLibraryAsResource2;
            }
            else {
                if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINER)) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), sourceMethod, str + " not found in any JAR file");
                    JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), sourceMethod, "Search " + str + " along the path specified as the java.library.path property");
                }
                return null;
            }
        }
    }
    
    private String getTmpDir() {
        String property = System.getProperty("java.io.tmpdir");
        if (property != null) {
            return property;
        }
        File tempFile = null;
        try {
            tempFile = File.createTempFile("tmp", "jmx");
            if (tempFile == null) {
                __Null _Null2 = null;
                if (tempFile != null) {
                    try {
                        if (!tempFile.delete()) {
                            JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "getTmpDir", "Failed to delete temp file");
                        }
                    }
                    catch (Exception thrown3) {
                        JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "getTmpDir", "Failed to delete temporary file", thrown3);
                    }
                }
                return _Null2;
            }
            else {
                File parentFile = tempFile.getParentFile();
                if (parentFile == null) {
                    __Null _Null = null;
                    if (tempFile != null) {
                        try {
                            if (!tempFile.delete()) {
                                JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "getTmpDir", "Failed to delete temp file");
                            }
                        }
                        catch (Exception thrown2) {
                            JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "getTmpDir", "Failed to delete temporary file", thrown2);
                        }
                    }
                    return _Null;
                }
                else {
                    String absolutePath = parentFile.getAbsolutePath();
                    if (tempFile != null) {
                        try {
                            if (!tempFile.delete()) {
                                JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "getTmpDir", "Failed to delete temp file");
                            }
                        }
                        catch (Exception thrown) {
                            JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "getTmpDir", "Failed to delete temporary file", thrown);
                        }
                    }
                    return absolutePath;
                }
            }
        }
        catch (Exception ex) {
            JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "getTmpDir", "Failed to determine system temporary dir");
            __Null _Null3 = null;
            if (tempFile != null) {
                try {
                    if (!tempFile.delete()) {
                        JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "getTmpDir", "Failed to delete temp file");
                    }
                }
                catch (Exception thrown4) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "getTmpDir", "Failed to delete temporary file", thrown4);
                }
            }
            return _Null3;
        }
        finally {
            if (tempFile != null) {
                try {
                    if (!tempFile.delete()) {
                        JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "getTmpDir", "Failed to delete temp file");
                    }
                }
                catch (Exception thrown5) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "getTmpDir", "Failed to delete temporary file", thrown5);
                }
            }
        }
    }
    
    private synchronized String loadLibraryAsResource(String s) {
        try {
            InputStream resourceAsStream = this.getResourceAsStream(s.replace(File.separatorChar, '/'));
            if (resourceAsStream != null) {
                try {
                    File file = new File(this.libraryDirectory);
                    file.mkdirs();
                    File file2 = Files.createTempFile(file.toPath(), s + ".", null, new FileAttribute[0]).toFile();
                    file2.deleteOnExit();
                    FileOutputStream fileOutputStream = new FileOutputStream(file2);
                    try {
                        byte[] array = new byte[4096];
                        int read;
                        while ((read = resourceAsStream.read(array)) >= 0) {
                            fileOutputStream.write(array, 0, read);
                        }
                    }
                    finally {
                        fileOutputStream.close();
                    }
                    if (file2.exists()) {
                        return file2.getAbsolutePath();
                    }
                }
                finally {
                    resourceAsStream.close();
                }
            }
        }
        catch (Exception thrown) {
            JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "loadLibraryAsResource", "Failed to load library : " + s, thrown);
            return null;
        }
        return null;
    }
    
    private static String removeSpace(String s) {
        return s.trim().replace(" ", "");
    }
    
    protected URL check(String s, URL url, String s2, MLetContent mLetContent) throws Exception {
        return url;
    }
    
    private Object loadSerializedObject(URL url, String replace) throws IOException, ClassNotFoundException {
        if (replace != null) {
            replace = replace.replace(File.separatorChar, '/');
        }
        if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINER)) {
            JmxProperties.MLET_LOGGER.logp(Level.FINER, MLet.class.getName(), "loadSerializedObject", url.toString() + replace);
        }
        InputStream resourceAsStream = this.getResourceAsStream(replace);
        if (resourceAsStream != null) {
            try {
                MLetObjectInputStream o = new MLetObjectInputStream(resourceAsStream, this);
                Object object = o.readObject();
                o.close();
                return object;
            }
            catch (IOException thrown) {
                if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINEST)) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "loadSerializedObject", "Exception while deserializing " + replace, thrown);
                }
                throw thrown;
            }
            catch (ClassNotFoundException thrown2) {
                if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINEST)) {
                    JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "loadSerializedObject", "Exception while deserializing " + replace, thrown2);
                }
                throw thrown2;
            }
        }
        else {
            if (JmxProperties.MLET_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "loadSerializedObject", "Error: File " + replace + " containing serialized object not found");
            }
            throw new Error("File " + replace + " containing serialized object not found");
        }
    }
    
    private Object constructParameter(String s, String s2) {
        Class<Object> clazz = (Class)this.primitiveClasses.get(s2);
        if (clazz != null) {
            try {
                return clazz.getConstructor(new Class[] { String.class }).newInstance(new Object[] { s });
            }
            catch (Exception thrown) {
                JmxProperties.MLET_LOGGER.logp(Level.FINEST, MLet.class.getName(), "constructParameter", "Got unexpected exception", thrown);
            }
        }
        if (s2.compareTo("java.lang.Boolean") == 0) {
            return Boolean.valueOf(s);
        }
        if (s2.compareTo("java.lang.Byte") == 0) {
            return new Byte(s);
        }
        if (s2.compareTo("java.lang.Short") == 0) {
            return new Short(s);
        }
        if (s2.compareTo("java.lang.Long") == 0) {
            return new Long(s);
        }
        if (s2.compareTo("java.lang.Integer") == 0) {
            return new Integer(s);
        }
        if (s2.compareTo("java.lang.Float") == 0) {
            return new Float(s);
        }
        if (s2.compareTo("java.lang.Double") == 0) {
            return new Double(s);
        }
        if (s2.compareTo("java.lang.String") == 0) {
            return s;
        }
        return s;
    }
    
    private synchronized void setMBeanServer(final MBeanServer server) {
        this.server = server;
        this.currentClr = (ClassLoaderRepository)AccessController.doPrivileged(new PrivilegedAction<ClassLoaderRepository>() {
            @Override
            public ClassLoaderRepository run() {
                return server.getClassLoaderRepository();
            }
        });
    }
}
